@@ -4,7 +4,8 @@ parentclass into the configuration of an FastAPI application.
 See `https://fastapi.tiangolo.com/advanced/settings/` as reference.
 
 Otherwise, check `https://github.com/EMMC-ASBL/oteapi-services/blob/master/app/main.py`
-for a direct example of an inclusion of the OTE api and its settings into an FastAPI instance.
+for a direct example of an inclusion of the OTE api and its settings into an FastAPI
+instance.
 """
 from pydantic import BaseSettings, Field
 
@@ -14,12 +15,14 @@ class OteApiCoreSettings(BaseSettings):
 
     expose_secrets: bool = Field(
         False,
-        description="Whether `SecretStr` in `pydantic` should be exposed or not.\n\n"
-        "!!! warning\n"
-        "    Depending on the configuration and user management of the services"
-        "    using oteapi-core, secrets might be readable by other users when serialized!"
-        "    This especially takes place when then models and configs are put into the cache."
-        "    Hence be careful while using this option in production.",
+        description="""Whether `SecretStr` in `pydantic` should be exposed or not.
+
+!!! warning
+    Depending on the configuration and user management of the services
+    using oteapi-core, secrets might be readable by other users when serialized!
+    This especially takes place when then models and configs are put into the cache.
+    Hence be careful while using this option in production.
+""",
     )
 
     class Config:
