@@ -35,7 +35,8 @@ class TripleStore:
     Init must initialize the triple store connection
 
     Args:
-        config (Union[TripleStoreConfig, Dict[str, Any]]): RDF triple-store configuration.
+        config (Union[TripleStoreConfig, Dict[str, Any]]): RDF triple-store
+            configuration.
 
     Attributes:
         config (TripleStoreConfig): The RDF triple-store configuration.
@@ -75,7 +76,7 @@ class TripleStore:
             host=self.config.agraphHost,
             port=self.config.agraphPort,
             user=self.config.user.get_secret_value(),  # type: ignore [union-attr]
-            password=self.config.password.get_secret_value(),  # type: ignore [union-attr]
+            password=self.config.password.get_secret_value(),  # type: ignore [union-attr]  # pylint: disable=line-too-long
         ) as connection:
             connection.addData(triples)
             connection.close()
@@ -128,7 +129,7 @@ class TripleStore:
             host=self.config.agraphHost,
             port=self.config.agraphPort,
             user=self.config.user.get_secret_value(),  # type: ignore [union-attr]
-            password=self.config.password.get_secret_value(),  # type: ignore [union-attr]
+            password=self.config.password.get_secret_value(),  # type: ignore [union-attr]  # pylint: disable=line-too-long
         ) as connection:
             update_query = connection.prepareUpdate(query=sparql_query)
             update_query.evaluate()
